#
# spec file for package perl-MIME-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name MIME-tools
Name:           perl-MIME-tools
Version:        5.515.0
Release:        1.4
# 5.515 -> normalize -> 5.515.0
%define cpan_version 5.515
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Tools to manipulate MIME messages
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DS/DSKOLL/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.59
BuildRequires:  perl(File::Temp) >= 0.18
BuildRequires:  perl(Mail::Field) >= 1.05
BuildRequires:  perl(Mail::Header) >= 1.01
BuildRequires:  perl(Mail::Internet) >= 1.0203
BuildRequires:  perl(Test::Deep)
Requires:       perl(File::Temp) >= 0.18
Requires:       perl(Mail::Field) >= 1.05
Requires:       perl(Mail::Header) >= 1.01
Requires:       perl(Mail::Internet) >= 1.0203
Provides:       perl(MIME::Body) = %{version}
Provides:       perl(MIME::Body::File)
Provides:       perl(MIME::Body::InCore)
Provides:       perl(MIME::Body::Scalar)
Provides:       perl(MIME::Decoder) = %{version}
Provides:       perl(MIME::Decoder::Base64) = %{version}
Provides:       perl(MIME::Decoder::BinHex) = %{version}
Provides:       perl(MIME::Decoder::Binary) = %{version}
Provides:       perl(MIME::Decoder::Gzip64) = %{version}
Provides:       perl(MIME::Decoder::NBit) = %{version}
Provides:       perl(MIME::Decoder::QuotedPrint) = %{version}
Provides:       perl(MIME::Decoder::UU) = %{version}
Provides:       perl(MIME::Entity) = %{version}
Provides:       perl(MIME::Field::ConTraEnc) = %{version}
Provides:       perl(MIME::Field::ContDisp) = %{version}
Provides:       perl(MIME::Field::ContType) = %{version}
Provides:       perl(MIME::Field::ParamVal) = %{version}
Provides:       perl(MIME::Head) = %{version}
Provides:       perl(MIME::Parser) = %{version}
Provides:       perl(MIME::Parser::FileInto)
Provides:       perl(MIME::Parser::FileUnder)
Provides:       perl(MIME::Parser::Filer)
Provides:       perl(MIME::Parser::Reader)
Provides:       perl(MIME::Parser::Results)
Provides:       perl(MIME::Tools) = %{version}
Provides:       perl(MIME::WordDecoder)
Provides:       perl(MIME::WordDecoder::ISO_8859)
Provides:       perl(MIME::WordDecoder::US_ASCII)
Provides:       perl(MIME::WordDecoder::UTF_8)
Provides:       perl(MIME::Words) = %{version}
%undefine       __perllib_provides
Recommends:     perl(Convert::BinHex)
%{perl_requires}

%description
Tools to manipulate MIME messages

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
PERL_USE_UNSAFE_INC=1 perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog examples README
%license COPYING

%changelog
* Thu Apr 25 2024 Tina Müller <timueller+perl@suse.de>
- updated to 5.515
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
  5.515	  2024-04-24  Dianne Skoll <dianne@skoll.ca>
  * VERSION 5.514 RELEASED
  * Fix the "version" setting in META.yml.  There are no other changes
  since 5.514.
* Wed Feb  7 2024 Tina Müller <timueller+perl@suse.de>
- updated to 5.514
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
  5.514	  2024-02-06  Dianne Skoll <dianne@skoll.ca>
  * VERSION 5.514 RELEASED
  * Move the guts of the ambiguous_content method to MIME::Head
  * Add MIME::Entity->ambiguous_content that returns true if
  this entity or any of its parts, recursively, has a MIME::Head
  whose ambiguous_content method returns true.
  * Keep MIME::Parser->ambiguous_content as a cached version of the
  most recently parsed $entity->ambiguous_content.
  * BUGFIX: Add some missing files to MANIFEST
  5.513	  2024-01-25  Dianne Skoll <dianne@skoll.ca>
  * VERSION 5.513 RELEASED
  * Add MIME::Parser->ambiguous_content to indicate one of several
    types of ambiguous MIME content that could be security risks.
  * Add the '@duplicate_parameters' pseudo-parameter to let caller
    detect duplicate MIME parameters on a MIME header.
  5.512	  2024-01-08  Dianne Skoll <dianne@skoll.ca>
  * VERSION 5.512 RELEASED
  * Use much larger chunk sizes for Base-64 encoding which reduces
  both encoding time and space overhead.
  https://rt.cpan.org/Ticket/Display.html?id=128400
  https://rt.cpan.org/Ticket/Display.html?id=130110
* Wed Jan  3 2024 Tina Müller <timueller+perl@suse.de>
- updated to 5.511
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
  5.511	  2024-01-02  Dianne Skoll <dianne@skoll.ca>
  * VERSION 5.511 RELEASED
  * Silence a warning if used with a development version of
  MIME::QuotedPrint
  https://rt.cpan.org/Ticket/Display.html?id=150118
  https://rt.cpan.org/Ticket/Display.html?id=149225
* Thu Jul  7 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.510
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
* Fri Apr  7 2017 coolo@suse.com
- updated to 5.509
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
  5.509	  2017-04-05  Dianne Skoll <dfs@roaringpenguin.com>
  * VERSION 5.509 RELEASED
  * Fix CPAN bug https://rt.cpan.org/Ticket/Display.html?id=120871
  Makefile.PL fails with no '.' in @INC
  * Fix CPAN bug https://rt.cpan.org/Ticket/Display.html?id=118262
  Test t/Ref.t fails on Windows install
  * Fix CPAN bug https://rt.cpan.org/Ticket/Display.html?id=119166
  MIME::Parser::parse_data() should check what it gets back...
  * Fix CPAN bug https://rt.cpan.org/Ticket/Display.html?id=119568
  Allow
  to be used as line-end delimeter when outputting MIME
  message.
* Wed Aug 31 2016 coolo@suse.com
- updated to 5.508
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
  5.508	  2016-08-29  Dianne Skoll <dfs@roaringpenguin.com>
  * VERSION 5.508 RELEASED
  * Fix test broken by Perl update
  https://rt.cpan.org/Ticket/Display.html?id=113887
* Mon May 30 2016 bwiedemann@suse.com
- Add MIME-tools-5.507-rt113887.patch from fedora
  to fix test failure with new MailTools
* Fri Oct  2 2015 coolo@suse.com
- updated to 5.507
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
  5.507	  2015-09-30  Dianne Skoll <dfs@roaringpenguin.com>
  * VERSION 5.507 RELEASED
  * Fix parsing bug
  https://rt.cpan.org/Public/Bug/Display.html?id=105455
  * Fix typo that broke MIME::Body::incore->open() on Perl 5.20
* Sat May  2 2015 coolo@suse.com
- updated to 5.506
  see /usr/share/doc/packages/perl-MIME-tools/ChangeLog
* Mon Jun 17 2013 coolo@suse.com
- updated to 5.504
  * Fix encoding of MIME parameters that contain a quoted
    string:  "like \"this"
    https://rt.cpan.org/Public/Bug/Display.html?id=80433
  * Suppress useless warnings from tests
    https://rt.cpan.org/Public/Bug/Display.html?id=80679
  * Fix long-standing bug in encode_mimewords that can
    break multibyte-encodings (eg, utf-8)
    https://rt.cpan.org/Public/Bug/Display.html?id=5462
  * Avoid inappropriately untainting data
    https://rt.cpan.org/Public/Bug/Display.html?id=67119
  * Localise $\ to avoid parsing problems if it's set elsewhere
    https://rt.cpan.org/Public/Bug/Display.html?id=71041
  * Improve exorcising of filenames
    https://rt.cpan.org/Public/Bug/Display.html?id=71677
  * Fix potential race condition in t/Smtpsend.t
    https://rt.cpan.org/Public/Bug/Display.html?id=68879
  * Allow native I/O on File::Handle objects
    https://rt.cpan.org/Public/Bug/Display.html?id=72538
  * Add "recommends Convert::BinHex" clause to Makefile.PL
    https://rt.cpan.org/Public/Bug/Display.html?id=72223
  * Add module_name to Makefile.PL
    https://rt.cpan.org/Public/Bug/Display.html?id=77138
  * Fix "Uninitialized value" warning
    https://rt.cpan.org/Public/Bug/Display.html?id=77190
  * Don't run t/Smtpsend.t on systems that lack fork()
    https://rt.cpan.org/Public/Bug/Display.html?id=77351
  * Add "use strict" everywhere
* Wed Mar  9 2011 vcizek@novell.com
- update to 5.502
  * NOTE to packagers (Debian, Red Hat, FreeBSD, etc.): Do not ship
  MIME::tools 5.500 or 5.501.  They both had serious bugs!
  * Fix parsing bug: https://rt.cpan.org/Ticket/Display.html?id=66025
  * Fix typo: https://rt.cpan.org/Ticket/Display.html?id=65387
  * Fix unit tests on Perl 5.8.x: https://rt.cpan.org/Ticket/Display.html?id=66188
  * Fix unit test failure on Win32:  (https://rt.cpan.org/Ticket/Display.html?id=66286)
* Mon Feb 21 2011 vcizek@novell.com
- update to 5.501
  * Add build_requires 'Test::Deep'; to Makefile (rt.cpan.org #64659)
  * Fix spelling errors (rt.cpan.org #64610)
  * Fix double-decoding bug when decoding RFC-2231-encoded parameters
  (rt.cpan.org #65162)
  * Fix inappropriate inclusion of CR characters in parsed headers
* Tue Jan 11 2011 vcizek@novell.com
- added dependency perl-Test-Deep
- updated to 5.500
  * (cleanup) IO-Stringy (specifically, IO::ScalarArray, IO::Lines, and
    IO::InnerFile) is no longer used
  * (ticket 22684) Fix deadlock in filter() when invoking external
    programs such as gzip. (Alexey Tourbin <at -at- altlinux.ru>)
  * Remove auto_install from Makefile.PL
  * (ticket 60931) If preamble is empty, make sure it's still empty after roundtripping through MIME::Entity
  * (ticket 63739) Properly decude RFC2231 encodings in attachment filenames
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Jul 16 2010 anicka@suse.cz
- update to 5.428
  * Only bind to localhost in smtpsend test, rather than to all
  available interfaces.
  * bugfixes
* Thu Mar 25 2010 ro@suse.de
- use perl_vendorlib in install section
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug 10 2009 anicka@suse.cz
- add dependency in perl-Convert-BinHex (bnc#527387)
* Mon Jul 27 2009 coolo@novell.com
- require File::Temp and don't install from cpan
* Thu Jan 15 2009 anicka@suse.cz
- enable testsuite (bnc#465976)
* Fri Jul 25 2008 anicka@suse.cz
- update to 5.427
  * (bugfix) fix remove_sig() on invalid multipart message
  * (bugfix) make_singlepart() no longer creates bizzare
  Content-Type: headers
  * (bugfix) process_part() no longer sets incorrect charset on empty
  parts
  * (bugfix) fix runtime warnings caused by incorrect pack() string
  * (docs) add "SEE ALSO" sections to POD docs
  * (docs) fix documentation of MIME::Head::get()
  * (packaging) Depend on IO::File 1.1.3, for its binmode() support
* Mon Mar 24 2008 anicka@suse.cz
- update to 5.426
  * (bugfix) require File::Temp 0.18 or newer, as we need seek()
  * (bugfix) Don't hang forever in t/Smtpsend.t
  * (bugfix) require Perl 5.8.0 or newer in Makefile.PL
  * (bugfix) encode_mimewords() no longer removes spaces between two
  encoded words
* Wed Nov 21 2007 anicka@suse.cz
- update to 5.425
  * (bugfix) A stub for MIME::Parser's tmp_recycling() method has been
    re-added to preserve compatibility.
* Fri Nov  9 2007 anicka@suse.cz
- update to 5.424
  * (bugfix)lines in $entity->body() should be newline-terminated.
* Mon Oct  8 2007 anicka@suse.cz
- update to 5.423
  * (enhancement) Use File::Temp for tempfile generation.
    MIME::Parser now has a tmp_dir() method for changing
    the temporary directory on a per-parser basis.
  * bugfixes
* Fri Jul 14 2006 anicka@suse.cz
- update to 5.420
  * Fix regression introduced in 5.419 -- quoted-printable
    encoding would sometimes fail on "textual" MIME parts.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 23 2005 schubi@suse.de
- update to version 5.419
* Fri Apr 15 2005 schubi@suse.de
- update to 5.417
* Mon Jan 10 2005 schwab@suse.de
- Fix file cleanup.
* Thu Nov  4 2004 choeger@suse.de
- update to v5.415
  (containing Bugfix ID#47851 - VUL-0: perl-Mime-tools passes some mime
  attachments)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 17 2003 choeger@suse.de
- use install_vendor and new %%perl_process_packlist macro
* Mon May 19 2003 choeger@suse.de
- remove installed (but unpackaged) file perllocal.pod
* Thu Aug  8 2002 mls@suse.de
- use sitearch macro
* Mon Jul 29 2002 mls@suse.de
- Fixed neededforbuild for perl-5.8.0
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Sun Jan 13 2002 link@suse.de
- update to v5.411a
* Fri May  4 2001 link@suse.de
- updated to v5.410 as all version below v5.313 have a nasty
  bug with evil filenames
* Thu Mar 29 2001 choeger@suse.de
- fixed requires
* Wed Nov 15 2000 choeger@suse.de
- long package name
- buildroot
* Mon Jul 24 2000 choeger@suse.de
- removed p_filspe from neededforbuild, because it is
  included in the perl package
* Wed Jul 19 2000 choeger@suse.de
- first package, v5.304
